#
# spec file for package simplescreenrecorder
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           simplescreenrecorder
Version:        0.3.8
Release:        3.7
Summary:        A feature-rich screen recorder that supports X11 and OpenGL
License:        GPL-3.0+
Group:          System/X11/Utilities
Url:            http://www.maartenbaert.be/simplescreenrecorder
Source:         https://github.com/MaartenBaert/ssr/archive/%{version}.tar.gz
Source9:        baselibs.conf

BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg8-devel
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Gui)       >= 5.1
BuildRequires:  pkgconfig(Qt5Widgets)   >= 5.1
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.1
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec) >= 53
BuildRequires:  pkgconfig(libavformat) >= 53
BuildRequires:  pkgconfig(libavutil) >= 51
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale) >= 2
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
%ifarch %{ix86} x86_64
# openGL apps:
Recommends:     libssr-glinject
%if %{_lib} == "lib64"
# 32bit openGL apps at 64bit system:
Suggests:       libssr-glinject-32bit
%endif
%endif

%description
SimpleScreenRecorder is a Linux program that was created to record programs
and games.

The original goal was to create a program that was just really simple to
use, the result is actually a pretty powerful program. It's 'simple' in
the sense that it's easier to use than ffmpeg/avconv or VLC, because it
has a straightforward user interface.

Features:
 * Graphical user interface (Qt-based).
 * Faster than VLC and ffmpeg/avconv.
 * Records the entire screen or part of it, or records OpenGL applications
   directly (similar to Fraps on Windows).
 * Synchronizes audio and video properly (a common issue with VLC and
   ffmpeg/avconv).
 * Reduces the video frame rate if your computer is too slow (rather than
   using up all your RAM like VLC does).
 * Fully multithreaded: small delays in any of the components will never
   block the other components, resulting is smoother video and better
   performance on computers with multiple processors.
 * Pause and resume recording at any time (either by clicking a button or by
   pressing a hotkey).
 * Shows statistics during recording (file size, bit rate, total recording
   time, actual frame rate, ...).
 * Can show a preview during recording, so you don't waste time recording
   something only to figure out afterwards that some setting was wrong.
 * Uses libav/ffmpeg libraries for encoding, so it supports many different
   codecs and file formats (adding more is trivial).
 * Sensible default settings: no need to change anything if you don't want to.
 * Tooltips for almost everything: no need to read the documentation to find
   out what something does.


%ifarch %{ix86} x86_64
%package -n libssr-glinject
Summary:        Simple Screen Recorder openGL plugin
License:        MIT
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libssr-glinject
This package provides nice openGL apps screencasting support
for Simple Screen Recorder. At 64bit system you may also
install libssr-glinject-32bit for 32bit openGL apps support.
%endif

%prep
%setup -q -n ssr-%{version}

%build
%ifarch %{ix86} x86_64
# /usr/include/qt5/QtCore/qglobal.h:1067:4: error: error "You must build
# your code with position independent code if Qt was built with
# -reduce-relocations. " "Compile your code with -fPIC (-fPIE is not
# enough)." error "You must build your code with position independent code
# if Qt was built with -reduce-relocations."
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%configure --with-qt5
%else
%configure \
           --with-qt5 \
           --disable-x86-asm \
           --disable-glinjectlib
%endif
make V=1 %{?_smp_mflags}

%install
%make_install V=1
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING *.txt *.md data/resources/about.htm
%{_bindir}/%{name}
%{_bindir}/ssr-glinject
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/%{name}
%{_mandir}/*/%{name}*
%{_mandir}/*/ssr-glinject*

%ifarch %{ix86} x86_64
%files -n libssr-glinject
%defattr(-,root,root)
%{_libdir}/libssr-glinject.so
%endif

%changelog
* Tue Nov 15 2016 dap.darkness@gmail.com
- Update to 0.3.8 (since 0.3.7):
  * Revert sample rate to 44.1 kHz for FLV container.
* Sun Oct 16 2016 dap.darkness@gmail.com
- Update to 0.3.7 (since 0.3.6):
  * Added support for latest FFmpeg/libav.
  * Make relaxed GLInject permissions actually work.
  * The backend now supports fragmented recording,
    but there is no GUI for this yet.
  * The default audio sample rate is now 48 kHz.
    This makes SSR compatible with Opus.
  * System tray icon now indicates errors during recording.
- Removed simplescreenrecorder-0.3.6-missing-include.diff
  as already provided via upstream tarball.
* Fri Jun 17 2016 dap.darkness@gmail.com
- `spec-cleaner`
- Added simplescreenrecorder-0.3.6-missing-include.diff
  to resolve bnc#985369.
- Tips from Packman's package.
- Enabled verbose make build.
* Tue Nov  3 2015 dap.darkness@gmail.com
- Update to 0.3.6 (since 0.3.3):
  * Fix bug in YUV420 fallback converter introduced by refactoring.
  * Allow user to start recording with hotkey or systray even when
    not on the recording page.
  * Fixed JACK input bug that could cause deadlocks in rare cases.
  * Added full support for NV12. If FFmpeg is compiled with NVENC
    support, this will allow you to use it.
  * Removed ssr-0.3.3-fix-disable-x86-asm.diff as merged.
  * Removed ssr-0.3.3-ffmpeg-pkgconfig.diff as merged by upstream.
- Qt4 → Qt5.
* Fri May  1 2015 dap.darkness@gmail.com
- baselibs.conf became mentioned in spec files as source
  to pass factory-auto.
* Mon Apr 27 2015 dap.darkness@gmail.com
- Fixed up libssr-glinject subpackage description (request#303989).
- Removed libssr-glinject static build (request#303989).
- Let's only suggest libssr-glinject-32bit to not install 32bit
  dependencies with default ssr installation.
- Dropped openSUSE < 13.* support.
* Thu Apr 23 2015 dap.darkness@gmail.com
- Packman → OBS;
- _service → tarball;
- `spec-cleaner`.
- Added ssr-0.3.3-ffmpeg-pkgconfig.diff
  to make build against openSUSE' ffmpeg possible
  ( https://github.com/MaartenBaert/ssr/commit/5929b ).
* Sat Jan 17 2015 dap.darkness@gmail.com
- Update to 0.3.3:
  * Fixed mistake in configure.ac that was causing
    libssr-glinject.so to be linked with unwanted libraries.
- Added ssr-0.3.3-fix-disable-x86-asm.patch.diff
  to fix --disable-x86-asm option
  ( https://github.com/MaartenBaert/ssr/commit/8043 ).
* Mon Jan  5 2015 dap.darkness@gmail.com
- Update to 0.3.2:
  * Added Qt5 support (optional, Qt4 is still the default).
  * Added YUV422, YUV444 and RGB support
    (YUV420 is still the default)
  * Added pixelformat and sampleformat codec options.
  * Added benchmark.
  * Improved RTL support.
  * Bugfixes.
* Fri Oct  3 2014 dap.darkness@gmail.com
- Update to 0.3.1:
  * no upstream changelog.
* Thu Jul  3 2014 dap.darkness@gmail.com
- Update to 0.3.0:
  * Added profile support.
  * New, more flexible OpenGL recording system
    (glinject-next branch merged).
  * More robust sound notifications.
  * Show progress dialog while flushing the encoders.
  * Improved hotkey support using XInput2.
  * Improved synchronizer.
  * Native support for mono microphones (plughw no longer needed).
  * Added source detection for ALSA.
  * Partially rewritten output backend.
  * Improved mouse following algorithm.
  * New icon.
  * Bugfixes.
* Tue Mar  4 2014 dap.darkness@gmail.com
- Update to 0.2.2:
  * Fix bug in Synchronizer that caused throttling to fail,
    resulting in excessive memory usage.
- Switching back to _service.
* Sun Mar  2 2014 dap.darkness@gmail.com
- Update to 0.2.1+git.2014.03.02:
  * Avoid build warning when assertions are disabled
  * Make sure that the resampler is only created when audio is
    enabled.
- Update to 0.2.1:
  * Correction to command-line help message.
  * Fix minor bug in drift recalculation in Synchronizer.
  * Bugfix: Don't stop the muxer before all packet queues
    are empty.
  * Make timestamps in file names Windows-compatible.
  * Make sure the segment is complete before destroying the
    synchronizer (shouldn't make a huge difference but let's do it
    anyway).
  * Add icons to distribution tarball.
- desktop_database_post(un) & icon_theme_cache_post(un)
  macros were added.
- enable-jack configure option was deleted as default.
- Temporary switching from _service to git tarball.
* Sat Feb 22 2014 dap.darkness@gmail.com
- Update to 0.2.0:
  * no upstream changelog.
- Switching back to _service.
* Wed Feb 12 2014 dap.darkness@gmail.com
- Update to 0.1.2+git.2014.02.09:
  * Jack support;
  * SoX Resampler became used;
  * cmake became used;
  * pkg-config became used;
  * "[VideoEncoder::EncodeFrame] Error: Keyframe flag was not set!"
    was fixed.
- Temporary switching from _service to git tarball.
* Mon Oct 28 2013 dap.darkness@gmail.com
- Update to 0.1.2:
  * no upstream changelog.
- Switched to configure option using instead of CPPFLAGS modifying.
* Sat Oct 19 2013 dap.darkness@gmail.com
- Update to 0.1.1:
  * no upstream changelog.
- Not exclude arm but include x86* only.
* Wed Sep 25 2013 dap.darkness@gmail.com
- Update to 0.1.0:
  * no upstream changelog.
- libssr-glinject-32bit became built and recommended
  to record x32 games at x64 hosts.
- libssr-glinject can't be built for arm:
  https://github.com/MaartenBaert/ssr/issues/30
- Service source_validator was removed because of
  https://bugs.links2linux.org/browse/PM-83
* Tue Jun 11 2013 dap.darkness@gmail.com
- Initial package.
